@@ -17,13 +17,12 @@ sub support();
 sub is_hostname;
 
 ## updated by autoconf
-$PATH_TO_SUDO    = "/usr/local/bin/sudo";
+$PATH_TO_SUDO    = "";
 $PATH_TO_RPCINFO = "/usr/bin/rpcinfo" ;
 $PATH_TO_LMSTAT  = "" ;
 $PATH_TO_SMBCLIENT = "/usr/local/bin/smbclient" ;
 $PATH_TO_MAILQ   = "/usr/bin/mailq";
 $PATH_TO_QMAIL_QSTAT = "";
-$PATH_TO_SNMPGET = "/usr/local/bin/snmpget";
 
 ## common variables
 $TIMEOUT = 15;
@@ -33,7 +32,7 @@ $TIMEOUT = 15;
 sub print_revision ($$) {
 	my $commandName = shift;
 	my $pluginRevision = shift;
-	print "$commandName v$pluginRevision (monitoring-plugins 2.4.0)\n";
+	print "$commandName v$pluginRevision (monitoring-plugins 2.2)\n";
 	print "The Monitoring Plugins come with ABSOLUTELY NO WARRANTY. You may redistribute\ncopies of the plugins under the terms of the GNU General Public License.\nFor more information about these matters, see the file named COPYING.\n";
 }
 
